@@ -1,9 +1,12 @@
-__version__ = '0.20.11'
+__version__ = '0.20.15'
 
 from data_connectors.slack import Slack
 from data_connectors.drive import Drive
 from data_connectors.gsheets import Gsheets
 from data_connectors.mssql import SQLServer
+from data_connectors.creds import load_creds
 from data_connectors.bigquery import BigQuery
 from data_connectors.calendar import Calendar
-from data_connectors.transform import Transform
\ No newline at end of file
+from data_connectors.transform import Transform
+
+load_creds()
\ No newline at end of file
